==> openshift-model-monitoring-5.11.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/OpsGenieConfigResponderFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class OpsGenieConfigResponderFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1alpha1.OpsGenieConfigResponderFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1alpha1.OpsGenieConfigResponderFluent<A>{
  public OpsGenieConfigResponderFluentImpl() {
  }
  public OpsGenieConfigResponderFluentImpl(io.fabric8.openshift.api.model.monitoring.v1alpha1.OpsGenieConfigResponder instance) {
    this.withId(instance.getId()); 
    this.withName(instance.getName()); 
    this.withType(instance.getType()); 
    this.withUsername(instance.getUsername()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String id;
  private java.lang.String name;
  private java.lang.String type;
  private java.lang.String username;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getId() {
    return this.id;
  }
  public A withId(java.lang.String id) {
    this.id=id; return (A) this;
  }
  public java.lang.Boolean hasId() {
    return this.id != null;
  }
  
  /**
   * Method is deprecated. use withId instead.
   */
  @java.lang.Deprecated
  public A withNewId(java.lang.String arg0) {
    return (A)withId(new String(arg0));
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public java.lang.String getUsername() {
    return this.username;
  }
  public A withUsername(java.lang.String username) {
    this.username=username; return (A) this;
  }
  public java.lang.Boolean hasUsername() {
    return this.username != null;
  }
  
  /**
   * Method is deprecated. use withUsername instead.
   */
  @java.lang.Deprecated
  public A withNewUsername(java.lang.String arg0) {
    return (A)withUsername(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OpsGenieConfigResponderFluentImpl that = (OpsGenieConfigResponderFluentImpl) o;
    if (id != null ? !id.equals(that.id) :that.id != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (username != null ? !username.equals(that.username) :that.username != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(id,  name,  type,  username,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/OpsGenieConfigResponderFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class OpsGenieConfigResponderFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1alpha1.OpsGenieConfigResponderFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1alpha1.OpsGenieConfigResponderFluent<A>{
  public OpsGenieConfigResponderFluentImpl() {
  }
  public OpsGenieConfigResponderFluentImpl(io.fabric8.openshift.api.model.monitoring.v1alpha1.OpsGenieConfigResponder instance) {
    this.withId(instance.getId()); 
    this.withName(instance.getName()); 
    this.withType(instance.getType()); 
    this.withUsername(instance.getUsername()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String id;
  private java.lang.String name;
  private java.lang.String type;
  private java.lang.String username;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getId() {
    return this.id;
  }
  public A withId(java.lang.String id) {
    this.id=id; return (A) this;
  }
  public java.lang.Boolean hasId() {
    return this.id != null;
  }
  
  /**
   * Method is deprecated. use withId instead.
   */
  @java.lang.Deprecated
  public A withNewId(java.lang.String arg0) {
    return (A)withId(new String(arg0));
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public java.lang.String getUsername() {
    return this.username;
  }
  public A withUsername(java.lang.String username) {
    this.username=username; return (A) this;
  }
  public java.lang.Boolean hasUsername() {
    return this.username != null;
  }
  
  /**
   * Method is deprecated. use withUsername instead.
   */
  @java.lang.Deprecated
  public A withNewUsername(java.lang.String arg0) {
    return (A)withUsername(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OpsGenieConfigResponderFluentImpl that = (OpsGenieConfigResponderFluentImpl) o;
    if (id != null ? !id.equals(that.id) :that.id != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (username != null ? !username.equals(that.username) :that.username != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(id,  name,  type,  username,  additionalProperties,  super.hashCode());
  }
  
}
